<?php
 /**
 * About module
 * http://www.aa-team.com
 * ======================
 *
 * @package		sp
 * @author		Andrei Dinca, AA-Team
 * @version		1.0
 */
! defined( 'ABSPATH' ) and exit;

if(class_exists('sp_dashboard') != true) {
	class sp_dashboard {
		
		const WXR_VERSION = '1.0';
		
		/**
		 * parent storage
		 *
		 * @var array
		 */
		public $parent = array();
		
		private $action = '';
		private $db_name_games = '';
		private $wp_import = null;
		
		/**
		 * The constructor
		 */
		public function __construct( $parent=array() )
		{
			// load parent
			$this->parent = $parent;
			$this->db_name_games = sp()->db->prefix . 'sp_reviews';
		}

		public function get_popular_cast()
		{
			$cast = array();
			$cast_results = get_terms( 'cast', array(
			    'orderby'    	=> 'count',
			    'order' 		=> 'DESC',
			    'number'		=> 12,
			    'hide_empty' 	=> 0
			) );

			if( $cast_results && count($cast_results) > 0 ){
				foreach ($cast_results as $key => $value) {

					$image_ID = get_term_meta( $value->term_id, '_thumbnail', true );

					$cast[$value->term_id] = array(
						'name' => $value->name,
						'count' => $value->count,
						'thumb' => ( trim($image_ID) != "" ? wp_get_attachment_image_src( $image_ID, array(200, 300) )[0] : '' ),
					);
				}
			}

			return $cast;
		}

		public function get_popular_products() {

			$products = array();

			// step 2, get all already play questions

			$popular_products = sp()->db->get_results( 
                "SELECT pm.meta_value as 'product_id', COUNT(pm.post_id) as 'reviews_nb' FROM " . sp()->db->prefix . "postmeta  as pm
		        INNER JOIN " . sp()->db->prefix . "posts as p ON p.ID = pm.post_id 
		        WHERE pm.meta_key = 'sp_product_id' 
		        AND p.post_status = 'publish' 
		        AND p.post_type = 'review' GROUP BY product_id ORDER BY reviews_nb DESC LIMIT 5", ARRAY_A );


            foreach ( $popular_products as $popular_product ) {
            	$post_thumbnail_id = get_post_thumbnail_id( $popular_product['product_id'] );

				if ( $post_thumbnail_id == '' || $post_thumbnail_id == null ){
					$image_src = wc_placeholder_img();
				} 
				else {
					$image_src = '<img src="' . wp_get_attachment_image_src( $post_thumbnail_id, 'thumbnail' )[0] . '" />';
				}

            	$popular_product['poster_thumbnail'] = $image_src;
            	$products[] = $popular_product;
            }
			
			return $products;
		}

		public function get_popular_reviewers() {
			$reviewers = array();

			$users_that_reviewed = sp()->db->get_results( 
                "SELECT pm.meta_value as 'review_id', COUNT(pm.post_id) as 'reviews_nb', p.post_author FROM " . sp()->db->prefix . "postmeta  as pm
		        INNER JOIN " . sp()->db->prefix . "posts as p ON p.ID = pm.post_id 
		        WHERE pm.meta_key = 'sp_product_id' 
		        AND p.post_status = 'publish' 
		        AND p.post_type = 'review' GROUP BY post_author ORDER BY reviews_nb DESC LIMIT 5", ARRAY_A );

            foreach ($users_that_reviewed as $user_that_reviewed) {
            	$user_that_reviewed['poster_thumbnail'] = get_avatar_url($user_that_reviewed['post_author']);
            	
            	$reviewers[] = $user_that_reviewed;
            }

			return $reviewers;
		}
		
		public function print_interface()
		{
			$html = array();
			$plugin_register = (string) get_option( "_" . sp()->alias . "_register_html" );

			$html[] = '<div id="sp_iw-section-content" class="sp_iw-section-dashboard">';
			$html[] = 	'</div>';


			$html[] = 	'<div class="sp_iw-section-dashboard-row">';
			
			$html[] = 		'<div class="sp_iw-dashboard-box sp_iw-box-size-2">';
			$html[] = 			'<div class="sp_iw-dashboard-box-content">';
			$html[] = 				'<h3 class="dashboard-box-label">'. ( esc_html__('Product Support', 'aa-woopagination') ) .'</h3>';
			$html[] = 				'<div class="sp_iw-dashboard-in-box-content">';
			$html[] = 					'<div class="sp_iw-row-icons">';
			$html[] = 						'<i class="fa fa-file-text-o"></i>';
			$html[] = 						'<div class="sp_iw-icons-title">';
			$html[] = 							'<p class="sp_iw-icons-strong">'. ( esc_html__('Online Documentation', 'aa-woopagination') ) .'</p>';
			$html[] = 							'<p>The best start for <strong>' . ( strip_tags( $this->parent->plugin_name ) ) . '</strong> beginners</p>';
			$html[] = 						'</div>';
			$html[] = 					'</div>';
			$html[] = 					'<div class="sp_iw-row-icons">';
			$html[] = 						'<i class="fa fa-life-ring"></i>';
			$html[] = 						'<div class="sp_iw-icons-title">';
			$html[] = 							'<p class="sp_iw-icons-strong">'. ( esc_html__('Ticket Support', 'aa-woopagination') ) .'</p>';
			$html[] = 							'<p>'. ( esc_html__('Direct help from our qualified support team', 'aa-woopagination') ) .'</p>';
			if( !$plugin_register && trim($plugin_register) == "" ){
				$html[] = 						'<a href="#" class="sp_iw-dashboard-button sp_iw-color-red sp_iw-require_register">'. ( esc_html__('Unlock Now', 'aa-woopagination') ) .'</a>';
			}else{
				$html[] = 						'<a href="http://support.aa-team.com/" target="_blank" class="sp_iw-dashboard-button sp_iw-color-yellow">'. ( esc_html__('Open New Ticket', 'aa-woopagination') ) .'</a>';
			}
			$html[] = 						'</div>';
			$html[] = 					'</div>';
			$html[] = 					'<div class="sp_iw-row-icons">';
			$html[] = 						'<i class="fa fa-money"></i>';
			$html[] = 						'<div class="sp_iw-icons-title">';
			$html[] = 							'<p class="sp_iw-icons-strong">'. ( esc_html__('Custom Modifications', 'aa-woopagination') ) .'</p>';
			$html[] = 							'<p>'. ( esc_html__('Direct help from our qualified dev and design team', 'aa-woopagination') ) .'</p>';
			if( !$plugin_register && trim($plugin_register) == "" ){
				$html[] = 						'<a href="#" class="sp_iw-dashboard-button sp_iw-color-red sp_iw-require_register">'. ( esc_html__('Unlock Now', 'aa-woopagination') ) .'</a>';
			}else{
				$html[] = 						'<a href="http://support.aa-team.com/custom-modifications/" target="_blank" class="sp_iw-dashboard-button sp_iw-color-yellow">'. ( esc_html__('Request a Quote', 'aa-woopagination') ) .'</a>';
			}
			$html[] = 						'</div>';
			$html[] = 					'</div>';
			$html[] = 				'</div>';
			$html[] = 			'</div>';
			$html[] = 		'</div>';
			
			
      		$current_user = wp_get_current_user();

			$html[] = 		'<div class="sp_iw-dashboard-box sp_iw-box-size-2">';
			$html[] = 			'<div class="sp_iw-dashboard-box-content">';

			if( $plugin_register && trim($plugin_register) != "" ){
				$html[] = 				'<h3 class="dashboard-box-label">Your plugin is activated</h3>';
				$html[] = 				'<div class="sp_iw-dashboard-in-box-content sp_iw-aa-register-text">' . ( $plugin_register ) . '</div>';
			}else{

				$html[] = 				'<h3 class="dashboard-box-label">Plugin Activation</h3>';
				$html[] = 				'<div class="sp_iw-dashboard-in-box-content">';
				$html[] = 					'<form class="sp_iw-register_plugin" action="" method="POST">';
				$html[] = 						'<div class="sp_iw-row-icons">';
				$html[] = 							'<i class="fa fa-key"></i>';
				$html[] = 							'<div class="sp_iw-icons-title">';
				$html[] = 								'<p class="sp_iw-icons-strong">'. ( esc_html__('Item Purchase Code (IPC)', 'aa-woopagination') ) .'</p>';
				$html[] = 								'<p>'. ( esc_html__('You can learn how to find your purchase code', 'aa-woopagination') ) .' <a href="http://support.aa-team.com/themes/default/assets/images/ipc-help.png" target="_blank">'. ( esc_html__('here', 'aa-woopagination') ) .'</a></p>';
				$html[] = 							'</div>';
				$html[] = 						'</div>';
				$html[] = 						'<input type="text" value="" style="width:100%" class="sp_iw-dashboard-input" name="sp_iw-validation-token" placeholder="IPC Code">';
				$html[] = 						'<input type="text" value="' . ( esc_attr( $current_user->user_email ) ) . '" style="width:100%" class="sp_iw-dashboard-input" name="sp_iw-validation-email" placeholder="'. ( esc_html__('Register email', 'aa-woopagination') ) .'">';
				$html[] = 						'<p>'. ( esc_html__('Reminder! The Regular License is for One Install Only!', 'aa-woopagination') ) .'</p>';
				$html[] = 						'<input type="button" class="sp_iw-dashboard-button sp_iw-color-yellow" value="'. ( esc_html__('Register the code', 'aa-woopagination') ) .'" />';
				$html[] = 					'</form>';
				$html[] = 				'</div>';
			}
			$html[] = 			'</div>';
			$html[] = 		'</div>';

			$html[] = 		'<div class="sp_iw-dashboard-box sp_iw-box-size-2">';
			$html[] = 			'<div class="sp_iw-dashboard-box-content">';
			$html[] = 				'<h3 class="dashboard-box-label">'. ( esc_html__('System Requirements', 'aa-woopagination') ) .'</h3>';
			$html[] = 				'<div class="sp_iw-dashboard-in-box-content">';
			$html[] = 					'<table class="sp_iw-system-req">';
			$html[] = 						'<tr>';
			$html[] = 							'<td width="55%">' . ( is_multisite() ? 'WPMU' : 'WP' ) . ' '. ( esc_html__('Version', 'aa-woopagination') ) .':</td>';
			$html[] = 							'<td><span class="sp_iw-success"><i class="fa fa-check-square"></i></span></td>';
			$html[] = 							'<td width="30%">' . get_bloginfo('version') . ' </td>';
			$html[] = 						'</tr>';

			$html[] = 						'<tr>';
			$html[] = 							'<td width="55%">'. ( esc_html__('Uploads folder writable', 'aa-woopagination') ) .'</td>';
			$html[] = 							'<td><span class="sp_iw-success"><i class="fa fa-check-square"></i></span></td>';
			$html[] = 							'<td width="30%"></td>';
			$html[] = 						'</tr>';

			$html[] = 						'<tr>';
			$html[] = 							'<td width="55%">'. ( esc_html__('Max Upload Size', 'aa-woopagination') ) .':</td>';
			$html[] = 							'<td><span class="sp_iw-success"><i class="fa fa-exclamation-circle"></i></span></td>';
			$html[] = 							'<td width="30%">' . ( size_format( wp_max_upload_size() ) ) . '</td>';
			$html[] = 						'</tr>';


			$allow_remote_get = (boolean) get_option( "_sp_allow_remote_get" );

			if( $allow_remote_get === false ){
				$response = wp_remote_get( 'http://google.com' );
				if( isset($response['body']) && trim($response['body']) != "" ){
					$allow_remote_get = true;
					update_option( "_sp_allow_remote_get", true );
				}
			}

			$html[] = 						'<tr>';
			$html[] = 							'<td width="55%">'. ( esc_html__('Remote GET', 'aa-woopagination') ) .':</td>';
			if( $allow_remote_get ){
				$html[] = 						'<td><span class="sp_iw-success"><i class="fa fa-exclamation-circle"></i></span></td>';
			}else{
				$html[] = 						'<td><span class="sp_iw-error"><i class="fa fa-check-square"></i></span></td>';
			}
			$html[] = 							'<td width="30%"></td>';
			$html[] = 						'</tr>';
			$html[] = 						'<tr>';
			$html[] = 							'<td>'. ( esc_html__('Your Theme', 'aa-woopagination') ) .'</td>';
			$template = get_option( 'template' );
			$themes = wp_get_themes();
			$theme = $themes[$template];

			$html[] = 							'<td><span class="sp_iw-success"><i class="fa fa-check-square"></i></span></td>';
			$html[] = 							'<td><a href="' . ( esc_url( admin_url( '/themes.php' ) ) ) . '"><img width="80" src="' . ( esc_url( $theme->get_screenshot() ) ) . '" /></a></td>';
			$html[] = 						'</tr>';

			$html[] = 						'<tr>';
			$html[] = 							'<td width="55%">'. ( esc_html__('WP DEBUG', 'aa-woopagination') ) .':</td>';
			$html[] = 							'<td rowspan="2">' . (  defined('WP_DEBUG') && WP_DEBUG === true ? 'YES' : "NO" ) . '</td>';
			$html[] = 						'</tr>';

			$html[] = 					'</table>';
			$html[] = 				'</div>';
			$html[] = 			'</div>';
			$html[] = 		'</div>';

			$html[] = 	'</div>';
			$html[] = '</div>';
			
			return implode( "\n", $html );
		}
	}
}