<?php
/**
 * sp Main manager.
 *
 * @package sp
 * @since   1.0
 */
if ( ! function_exists( 'sp' ) ) {
	/**
	 * sp manager.
	 * @since 1.0
	 * @return sp
	 */
	function sp() {
		global $sp;

		return $sp;
	}
}

if ( ! function_exists( 'sp_Settings' ) ) {
	/**
	 * sp manager.
	 * @since 1.0
	 * @return sp_Settings
	 */
	function sp_Settings() {
		return new sp_Settings();
	}
}

if ( ! function_exists( 'sp_get_templates_list' ) ) {
	function sp_get_templates_list( $include_default=true, $ret_what='name' ) {
		$ret = array();
		if ( $include_default ) {
			$ret = array_merge($ret, array(
				'default' 		=> array(
					'name'		=> 'Default',
					'thumb'		=> '',
				),
			));
		}
		$ret = array_merge($ret, array(
			'template1' 		=> array(
				'name'		=> 'Template 1',
				'thumb'		=> '1.jpg',
			),
			'template2' 		=> array(
				'name'		=> 'Template 2',
				'thumb'		=> '2.jpg',
			)
		));

		if ( 'both' == $ret_what) ;
		else {
			//$ret = array_column( $ret, $ret_what );
			$ret = array_filter( array_combine( array_keys($ret), array_column($ret, $ret_what) ) );
		} 
		return $ret;
	}
}



if ( ! function_exists( 'sp_Social' ) ) {
	/**
	 * sp manager.
	 * @since 1.0
	 * @return sp_Social
	 */
	function sp_Social() {
		return new sp_Social();
	}
}

if ( ! function_exists( 'sp_Settings_Build_Options' ) ) {
	/**
	 * sp manager.
	 * @since 1.0
	 * @return sp_Settings
	 */
	function sp_Settings_Build_Options( $options=array(), $box_id='' ) {
		return sp_Settings()->build_options( $options, $box_id );
	}
}


if ( ! function_exists( 'sp_Woocommerce' ) ) {
	/**
	 * sp manager.
	 * @since 1.0
	 * @return sp_Settings
	 */
	function sp_Woocommerce() {
		return new sp_Woocommerce();
	}
}

if ( ! function_exists( 'sp_Load_Options' ) ) {
	/**
	 * sp manager.
	 * @since 1.0
	 * @return sp_Settings
	 */
	function sp_Load_Options( $dir ) {
	    new sp_Settings(); // save settings first!
	    
		$options = array();
			
		// find if we have a options.php into the same folder
		$options_file = $dir . '/options.php';
		if( is_file($options_file) ){
			
			ob_start();
			require_once $options_file;
			
			$content = ob_get_contents();
			ob_clean();
 
			if( trim($content) != "" ){
				$options = json_decode( $content, true );
			}
		}
		return $options;
	}
}

if ( ! function_exists( 'sp_mapper' ) ) {
	/**
	 * Shorthand for sp Mapper.
	 * @since 1.0
	 * @return sp_Mapper
	 */
	function sp_mapper() {
		return sp()->mapper();
	}
}
if ( ! function_exists( 'sp_settings' ) ) {
	/**
	 * Shorthand for sp settings.
	 * @since 1.0
	 * @return sp_Settings
	 */
	function sp_settings() {
		return sp()->settings();
	}
}
if ( ! function_exists( 'sp_path_dir' ) ) {
	/**
	 * Get file/directory path in sp.
	 *
	 * @param string $name - path name
	 * @param string $file
	 *
	 * @since 1.0
	 * @return string
	 */
	function sp_path_dir( $name, $file = '' ) {
		return sp()->path( $name, $file );
	}
}
if ( ! function_exists( 'sp_upload_dir' ) ) {
	/**
	 * Temporary files upload dir;
	 * @since 1.0
	 * @return string
	 */
	function sp_upload_dir() {
		return sp()->uploadDir();
	}
}
if ( ! function_exists( 'sp_path_dir' ) ) {
	/**
	 * Get file/directory path in sp.
	 *
	 * @param string $name - path name
	 * @param string $file
	 *
	 * @since 4.2
	 * @return string
	 */
	function sp_path_dir( $name, $file = '' ) {
		return sp()->path( $name, $file );
	}
}
if ( ! function_exists( 'sp_post_param' ) ) {
	/**
	 * Get param value from $_POST if exists.
	 *
	 * @param $param
	 * @param $default
	 *
	 * @since 1.0
	 * @return null|string - null for undefined param.
	 */
	function sp_post_param( $param, $default = null ) {
		return isset( $_POST[ $param ] ) ? $_POST[ $param ] : $default;
	}
}
if ( ! function_exists( 'sp_get_param' ) ) {
	/**
	 * Get param value from $_GET if exists.
	 *
	 * @param $param
	 * @param $default
	 *
	 * @since 1.0
	 * @return null|string - null for undefined param.
	 */
	function sp_get_param( $param, $default = null ) {
		return isset( $_GET[ $param ] ) ? $_GET[ $param ] : $default;
	}
}
if ( ! function_exists( 'sp_request_param' ) ) {
	/**
	 * Get param value from $_REQUEST if exists.
	 *
	 * @param $param
	 * @param $default
	 *
	 * @since 4.4
	 * @return null|string - null for undefined param.
	 */
	function sp_request_param( $param, $default = null ) {
		return isset( $_REQUEST[ $param ] ) ? $_REQUEST[ $param ] : $default;
	}
}
if ( ! function_exists( 'sp_action' ) ) {
	/**
	 * Get sp special action param.
	 * @since 1.0
	 * @return string|null
	 */
	function sp_action() {
		$sp_action = 'dashboard';
		if ( isset( $_GET['sp_action'] ) ) {
			$sp_action = $_GET['sp_action'];
		} elseif ( isset( $_POST['sp_action'] ) ) {
			$sp_action = $_POST['sp_action'];
		}

		return $sp_action;
	}
}

if ( ! function_exists( 'sp_asset_url' ) ) {
	/**
	 * Get full url for assets.
	 *
	 * @param string $file
	 *
	 * @since 4.2
	 * @return string
	 */
	function sp_asset_url( $file ) {
		return sp()->assetUrl( $file );
	}
}

if ( ! function_exists( 'sp_templates_url' ) ) {
	/**
	 * Get full url for assets.
	 *
	 * @param string $file
	 *
	 * @since 4.2
	 * @return string
	 */
	function sp_templates_url( $file ) {
		return sp()->templatesUrl( $file );
	}
}

if ( ! function_exists( 'sp_locate_template' ) ) {
	function sp_locate_template( $template_name, $template_path = '', $default_path = '' ) 
	{
	    if ( ! $template_path ) {
	        $template_path = 'templates/';
	    }

	    if ( ! $default_path ) {
	        $default_path = sp()->path( 'TEMPLATES_DIR', '' );
	    }
 
	    // Look within passed path within the theme - this is priority.
	    $template = locate_template(
	        array(
	            trailingslashit( $template_path ) . $template_name,
	            $template_name
	        )
	    );

	    // Get default template/
	    if ( ! $template ) {
	        $template = $default_path . $template_name;
	    }

	    // Return what we found.
	    return apply_filters( 'sp_locate_template', $template, $template_name, $template_path );
	}
}


if ( ! function_exists( 'sp_Get_IP' ) ) {
	function sp_Get_IP() 
	{
		//Just get the headers if we can or else use the SERVER global
		if ( function_exists( 'apache_request_headers' ) ) {
			$headers = apache_request_headers();
		} else {
			$headers = $_SERVER;
		}
		//Get the forwarded IP if it exists
		if ( array_key_exists( 'X-Forwarded-For', $headers ) && filter_var( $headers['X-Forwarded-For'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 ) ) {
			$the_ip = $headers['X-Forwarded-For'];
		} elseif ( array_key_exists( 'HTTP_X_FORWARDED_FOR', $headers ) && filter_var( $headers['HTTP_X_FORWARDED_FOR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 )
		) {
			$the_ip = $headers['HTTP_X_FORWARDED_FOR'];
		} else {
			$the_ip = filter_var( $_SERVER['REMOTE_ADDR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 );
		}
		return $the_ip;
	}
}

/**
 * Plugin name for sp_time_elapsed_string.
 *
 * @since 1.0
 * @return string
 */
if ( ! function_exists( 'sp_time_elapsed_string' ) ) {
	function sp_time_elapsed_string($ptime)
	{
	    $etime = time() - $ptime;
	
	    if ($etime < 1)
	    {
	        return '0 seconds';
	    }
	
	    $a = array( 365 * 24 * 60 * 60  =>  'year',
	                 30 * 24 * 60 * 60  =>  'month',
	                      24 * 60 * 60  =>  'day',
	                           60 * 60  =>  'hour',
	                                60  =>  'minute',
	                                 1  =>  'second'
	                );
	    $a_plural = array( 'year'   => 'years',
	                       'month'  => 'months',
	                       'day'    => 'days',
	                       'hour'   => 'hours',
	                       'minute' => 'minutes',
	                       'second' => 'seconds'
	                );
	
	    foreach ($a as $secs => $str)
	    {
	        $d = $etime / $secs;
	        if ($d >= 1)
	        {
	            $r = round($d);
	            return $r . ' ' . ($r > 1 ? $a_plural[$str] : $str) . ' ago';
	        }
	    }
	}
}


/**
 * Plugin name for sp.
 *
 * @since 1.0
 * @return string
 */
function sp_plugin_name() {
	return sp()->pluginName();
}