<?php
class smartPaginateFrontpage {
    public  $options; // array containing the optionsions
    private $smartPaginate;
    public  $curr_style;
    public  $current_theme;
    
    // default type
    public $type = 'posts';

    public $the_plugin = array();

    public $settings   = array();

    public $pagination_printed = false;

    function __construct( $the_plugin=array() ) {

        $this->current_theme = wp_get_theme();

        $this->loadExtraStyles();

        $this->settings = $the_plugin->settings;
		
        $this->options = array(
            'url_home'      => home_url("/"),
            'title'         => 'Pages:',
            'nextpage'      => trim( $this->settings['next_label'] ) != "" ? esc_html( $this->settings['next_label'] ) : ' ',
            'previouspage'  => trim( $this->settings['previous_label'] ) != "" ? esc_html( $this->settings['previous_label'] ) : ' ',
            'before'        => '<div class="sp-navigation">',
            'after'         => '</div>',
            'empty'         => true,
            'range'         => trim( $this->settings['sp_range'] ) != "" ? $this->settings['sp_range']  : 5,
            'anchor'        => trim( $this->settings['sp_anchor'] )     != "" ? $this->settings['sp_anchor']  : 1,
            'gap'           => trim( $this->settings['sp_gap_number'] )         != "" ? $this->settings['sp_gap_number'] : 3
        );
        
        

        foreach ($this->options as $key => $value) {
            if ($value == 'true') {
                $this->options[$key] = true;
            }
            if ($value == 'false') {
                $this->options[$key] = false;
            }
        }
        

        if( !isset( $this->settings['custom_css_selector'] ) || trim( $this->settings['custom_css_selector'] ) == '' && $this->current_theme->get('TextDomain') != 'kingdom' && $this->current_theme->get('TextDomain') != 'bravostore' && $this->current_theme->get('TextDomain') != 'Avada' ){
            if( $this->settings['where_to_show'] == 'both'){
                add_filter('navigation_markup_template', array($this, 'smart_paginate'), 10, 2 ); 

                add_action('woocommerce_after_shop_loop', array($this, 'smart_paginate'), 10, 2 );
            }
            elseif ( $this->settings['where_to_show'] == 'woocommerce' ) {
                add_action('woocommerce_after_shop_loop', array($this, 'smart_paginate'), 10, 2 );
            }
            else {
                add_filter('navigation_markup_template', array($this, 'smart_paginate'), 10, 2 ); 
            }
        }
        else {
            add_action( 'loop_end', array($this, 'custom_pagination_replace') );
        }
    }

    public function loadExtraStyles()
    {
        wp_enqueue_style( 'sp-moonicon-css', SP()->path('ASSETS_URL') . '/moon-icons.css', array(), '1.0' );
        wp_enqueue_style( 'sp-heebo-font', 'https://fonts.googleapis.com/css?family=Heebo', array(), '1.0' );
        wp_enqueue_script( 'sp-frontend-js', SP()->path('ASSETS_URL') . '/frontend.js', array('jquery'), '1.0', true );
    }

    public function custom_pagination_replace( $content='' )
    {

        $paginated_links = array();

        $paginated_links['current_theme'] = $this->current_theme->get('TextDomain');

        if (  trim( $this->settings['custom_css_selector'] ) == '' ) {

            switch( $paginated_links['current_theme'] ) {
                case 'kingdom':
                    $paginated_links['selector'] = '.pagination-container';
                    break;
                case 'bravostore':
                    $paginated_links['selector'] = '.classic-pagination';
                    break;
                case 'Avada':
                    $paginated_links['selector'] = '.fusion-blog-archive .pagination';
                    break;
            }
        }
        else {
            $paginated_links['selector'] = $this->settings['custom_css_selector'];
        }

        $paginated_links['paginated_array'] = $this->paginate();
        

        wp_localize_script( 'sp-frontend-js', 'sp_custom_css_selector', $paginated_links );

        return $content;
    }

    /**
     * Pagination based on options
     */
    public function paginate( $args = false ) {
        if ($this->type === 'comments' && !get_option('page_comments'))
            return;

        $r = wp_parse_args( $args, $this->options);
        extract($r, EXTR_SKIP);

        if (!isset($page) && !isset($pages)) {
            global $wp_query;

            if ($this->type === 'posts') {
                $page = get_query_var('paged');
                $posts_per_page = intval(get_query_var('posts_per_page'));
                $pages = intval(ceil($wp_query->found_posts / $posts_per_page));
            } else {
                $page = get_query_var('cpage');
                $comments_per_page = get_option('comments_per_page');
                $pages = get_comment_pages_count();
            }
            $page = !empty($page) ? intval($page) : 1;
        }


        $prevlink = ($this->type === 'posts') ? esc_url(get_pagenum_link($page - 1)) : get_comments_pagenum_link($page - 1);
        $nextlink = ($this->type === 'posts') ? esc_url(get_pagenum_link($page + 1)) : get_comments_pagenum_link($page + 1);

       
        // get current style
        $curr_style = str_replace("preview.png", '', $this->settings['template_default'], $curr_style);

        $curr_style = str_replace($this->settings['template_default'], ( 'model-' . $this->settings['template_default'] . '/' ), $curr_style );
        
        $model = str_replace("/", '', str_replace("style", '', $curr_style));

        $this->curr_style = SP()->path('ASSETS_URL', 'style/') . $curr_style . 'css.css'; 

       
        if( $this->settings['template_font_family'] != 'Arial' ){

            if( $this->settings['template_font_family'] == 'Bebas Neue Bold' ){
                echo '<link rel="stylesheet" type="text/css" href="' . SP()->path('ASSETS_URL', 'fonts/bebasneuebold/font.css') . '">' . PHP_EOL;
            }else{
                echo '<link rel="stylesheet" type="text/css" href="http://fonts.googleapis.com/css?family=' . $this->settings['template_font_family'] . '">' . PHP_EOL;
            }
            
        }
        
        $output = '<link rel="stylesheet" type="text/css" media="all" href="' . $this->curr_style . '" />' . PHP_EOL;
        $output .= '<style type="text/css">' . PHP_EOL;
        
        $output .=    'ul#pagination.' . ($model) . ' li {font-size: ' . ( (int) $this->settings['template_font_size'])  . 'px;}' . PHP_EOL;
        
        $output .=    'ul#pagination.' . ($model) . ' li a:link, ul#pagination.' . ($model) . ' li a:visited {color: ' . ($this->settings['link_text_color']) . ';}' . PHP_EOL;
        $output .=    'ul#pagination.' . ($model) . ' li a:hover {color: ' . ($this->settings['hover_link_text_color']) . ';}' . PHP_EOL;
        $output .=    'ul#pagination.' . ($model) . ' li.active {color: ' . ($this->settings['current_item_text_color']) . ';}' . PHP_EOL;
        $output .=    'ul#pagination {display: block; clear: both; margin-bottom: 20px; margin-top: 20px;}' . PHP_EOL;
        

        if($this->settings['template_font_family'] != 'Arial'){
            $output .= "
                ul#pagination.{$model} li {
                    font-family: '".($this->settings['template_font_family'])."', Arial, serif;
                }
            ";
        }

        if( $this->settings['where_to_show'] == 'both' || $this->settings['where_to_show'] == 'woocommerce' ){
            $output .= 'body .woocommerce-pagination { display: none; }' . PHP_EOL;
        }

        $output .= '</style>' . PHP_EOL; 
        
        $output .= stripslashes($before);
        if ($pages > 1) {
            if ( $this->settings['where_to_show'] == 'both' && isset($wp_query->query['post_type']) && $wp_query->query['post_type'] == 'product' ) {
                $output .= '<div class="sp-pagination-container">';
            }
            $output .=  '<ul class="' . ($model) .'" id="pagination" data-paged="' . ( $page ) .'">' . PHP_EOL;
            
            $ellipsis =     "<li><a href='javascript://'>...</a></li>" . PHP_EOL;
            if ($page > 1 && !empty($previouspage)) {
                $output .= sprintf('<li class="previous-off"><a href="%s">%s</a></li>', $prevlink, stripslashes($previouspage));
            }

            $min_links = $range * 2 + 1;
            $block_min = min($page - $range, $pages - $min_links);
            $block_high = max($page + $range, $min_links);
            $left_gap = (($block_min - $anchor - $gap) > 0) ? true : false;
            $right_gap = (($block_high + $anchor + $gap) < $pages) ? true : false;

            if ($left_gap && !$right_gap) {
                $output .= sprintf('%s%s%s', $this->paginate_loop(1, $anchor), $ellipsis, $this->paginate_loop($block_min, $pages, $page)
                );
            } else if ($left_gap && $right_gap) {
                $output .= sprintf('%s%s%s%s%s', $this->paginate_loop(1, $anchor), $ellipsis, $this->paginate_loop($block_min, $block_high, $page), $ellipsis, $this->paginate_loop(($pages - $anchor + 1), $pages)
                );
            } else if ($right_gap && !$left_gap) {
                $output .= sprintf('%s%s%s', $this->paginate_loop(1, $block_high, $page), $ellipsis, $this->paginate_loop(($pages - $anchor + 1), $pages)
                );
            } else {
                $output .= $this->paginate_loop(1, $pages, $page);
            }

            if ($page < $pages && !empty($nextpage)) {
                $output .= sprintf('<li class="next"><a href="%s">%s</a></li>', $nextlink, stripslashes($nextpage));
            }
            $output .=  "</ul>";

            $output .= '<div class="sp-pagination-overlay" data-paged="' . ( $page ) .'"></div>';
        }
        $output .= stripslashes($after);

        // for some models display total items etc
        if( $this->settings['template_default'] == 3 ){
             $output .= '<div class="sp-pagination-extra-info">';
             $output .=     '<span class="sp-pagination-total-items">' . $wp_query->found_posts . ' ' .  esc_html__('items', 'aa-woopagination') . '</span>';
             $output .=     '<span class="sp-pagination-extra-pages">' . esc_html__('Page', 'aa-woopagination') . ' '  . $page . ' ' . esc_html__('of', 'aa-woopagination') . ' ' . $page . '</span>';
             $output .= '</div>';
        }

        if( $this->settings['where_to_show'] == 'both' && isset($wp_query->query['post_type']) && $wp_query->query['post_type'] == 'product' ) {
            // close main container
            $output .= '</div>';
        }

        // clearfix


        if ($pages > 1 || $empty ) {
            echo $output;
            echo '<div class="sp-clearfix" style="clear: both;"></div>';
        }

        //return $output;
    }

    /**
     * Helper function for pagination which builds the page links.
     */
    public function paginate_loop($start, $max, $page = 0) {
        $output = "";
        
        $curr_style = str_replace("preview.png", '', $this->settings['template_default']);
        
        $model = str_replace("/", '', str_replace("style", '', $curr_style));
        for ($i = $start; $i <= $max; $i++) {
            $p = ($this->type === 'posts') ? esc_url(get_pagenum_link($i)) : get_comments_pagenum_link($i);
            $output .= ( $page == intval($i)) ? "<li class='active'>".($model == 'model-9' ? '[' : '')."$i".($model == 'model-9' ? ']' : '')."</li>" : "<li><a href='$p' title='$i'>".($model == 'model-9' ? '[' : '')."$i".($model == 'model-9' ? ']' : '')."</a></li>";
        }
        return $output;
    }


    /**
     * Pagination function to use for posts
     */
    public function smart_paginate($args = false) {
        return $this->paginate($args);
    }

    /**
     * Pagination function to use for post comments
     */
    public function smart_paginate_comments($args = false) {
        $this->type = 'comments';
        return $this->paginate($args);
    }
    

}