<?php
/*
 * Define class sp_Settings
 * Make sure you skip down to the end of this file, as there are a few
 * lines of code that are very important.
 */
!defined('ABSPATH') and exit;

if (class_exists('sp_Settings') != true) {
    
    class sp_Settings
    {
        /*
         * Some required plugin information
         */
        const VERSION = '1.0';
		
		private $save_status = false;
        
        /*
         * Required __construct() function that initalizes the sp_Settings
         */
        public function __construct()
        {
        	$this->save_settings();
        }
		
		private function save_settings()
		{
            $new_settings = $_REQUEST;
			  
            if( isset( $new_settings['sp_Import_Settings'] ) && $new_settings['sp_Import_Settings'] != null ){
                $new_settings = $new_settings['sp_Import_Settings'];
                
                $old_settings = get_option('sp_Import_Settings');

                $old_template = $old_settings['template_default'];
                $new_template = $new_settings['template_default'];

                if ( $old_template != $new_template ) {
                    // load template default settings from their directory
                   require_once( sp()->PATH('ASSETS_DIR', 'style/model-' . $new_template . '/settings.php') );

                   $model_class_name = 'sp_Model' . $new_template  . '_Settings';
                   $model_settings = new $model_class_name();

                   $model_settings = array_merge( $old_settings, $model_settings->get_model_settings() );

                   $_REQUEST['sp_Import_Settings'] = $model_settings;

                }
            }

			$form_saved = isset( $_REQUEST['sp-form-saved'] ) ? (boolean) $_REQUEST['sp-form-saved'] : false;
			$box_id = isset( $_REQUEST['box_id'] ) ? (string) $_REQUEST['box_id'] : '';
			if( $form_saved === true && trim($box_id) != "" ){
				$params = isset( $_REQUEST[$box_id] ) ? $_REQUEST[$box_id] : array();
				
				if( count($params) > 0 ){
					update_option( $box_id, $params );
					$this->save_status = true;


				} 
			}
		}
        
        /*
         * Build options, method
         * ---------------------
         * this will create you interface via options array elements
         */
        public function build_options($options = array(), $box_id = '')
        {
            // reset as array, this will stock all the html content, and at the end return it
            $html = array();
            
            $noRowElements = array(
                'message',
                'html',
                'tmdb-login',
                'app'
            );
            $settings      = array();
            
            // get the values from DB
            $settings = get_option( $box_id );
			
            $html[] = '<form method="POST" class="sp-form" id="' . ($box_id) . '" action="">';
            
			$html[] = '<div class="sp-message sp-success ' . ( $this->save_status == false ? 'sp-display-none' : '' ) . '">Saved successfully!</div>';
            // create a hidden input for sending the prefix
            $html[] = 	'<input type="hidden" name="box_id" value="' . ($box_id) . '" />';
			$html[] = 	'<input type="hidden" name="sp-form-saved" value="1" />';
            
            $box = isset($options) ? $options : array();
            $html[] = $this->tabs_header($box); // tabs html header
 
            // loop the box elements
            if (isset($options['elements']) && count($options['elements']) > 0) {
                
                // loop the box elements now
                foreach ($options['elements'] as $elm_id => $value) {
                    
                    // some helpers. Reset an each loop, prevent collision
                    $val          = '';
                    $select_value = '';
                    $checked      = '';
                    $option_name  = isset($option_name) ? $option_name : '';
                    
                    // Set default value to $val
                    if (isset($value['std'])) {
                        $val = $value['std'];
                    }
                   
                    // If the option is already saved, ovveride $val
                    if ( ( $value['type'] != 'info' ) ) {
                        if ( isset($settings[($elm_id)] )
                            && (
                                ( !is_array($settings[($elm_id)]) && trim($settings[($elm_id)]) != "" )
                                ||
                                ( is_array($settings[($elm_id)]) )
                            )
                        ) {
                                $val = $settings[( $elm_id )];

                                // Striping slashes of non-array options
                                if ( !is_array($val) ) {
                                    $val = stripslashes( $val );
                                }
                        }
                    }
                    
                    // If there is a description save it for labels
                    $explain_value = '';
                    if (isset($value['desc'])) {
                        $explain_value = $value['desc'];
                    }
                    
                    if (!in_array($value['type'], $noRowElements)) {
                        // the row and the label 
                        $html[] = '<div class="sp-form-row' . ($this->tabs_elements($box, $elm_id)) . '">
							   <label for="' . ($elm_id) . '">' . (isset($value['title']) ? $value['title'] : '') . '</label>
							   <div class="sp-form-item">';
                    }
                    
                    switch ($value['type']) {
                        
                        // Basic text input
                        case 'text':
                            $html[] = '<input ' . (isset($value['force_width']) ? "style='width:" . ($value['force_width']) . "px;'" : '') . ' id="' . esc_attr($elm_id) . '" name="' . ( $box_id ) . '[' . esc_attr( $elm_id ) . ']" type="text" value="' . esc_attr($val) . '" />';
                            break;
							
						// Wordpress color picker input
						case 'color_picker':
							$html[] = '<input class="sp-wp-color-picker" ' . ( isset($value['force_width']) ? "style='width:" . ( $value['force_width'] ) . "px;'" : '' ) . ' id="' . esc_attr( $elm_id ) . '" name="' . ( $box_id ) . '[' . esc_attr( $elm_id ) . ']" type="text" value="' . esc_attr( $val ) . '" />';
						break;

                        // Basic checkbox input
                        case 'checkbox':
                            $html[] = '<input ' . (isset($value['force_width']) ? "style='width:" . ($value['force_width']) . "px;'" : '') . ' ' . ($val == true ? 'checked' : '') . ' id="' . esc_attr($elm_id) . '" name="' . ( $box_id ) . '[' . esc_attr( $elm_id ) . ']" type="checkbox" value="" />';
                            break;
                        
                        // Basic checkbox input
                        case 'image_radio':

                            if( isset($value['options']) && count($value['options']) > 0 ){
                                $html[] = '<div class="sp-select-wrapper">';
                                    foreach ($value['options'] as $option_key => $option_value ) {
                                        $html[] =   '<label class="sp-select-item ' . ($val == $option_key ? 'select-on' : '') . '">';
                                        $html[] =       '<span>' . ( $option_value['caption'] ) . '</span>';
                                        $html[] =       '<img src="' . ( $option_value['img'] ) . '" />';
                                        $html[] =       '<input name="' . ( $box_id ) . '[' . esc_attr( $elm_id ) . ']" ' . ($val == $option_key ? 'checked' : '') . ' type="radio" value="' . ( $option_key ) . '" />';
                                        $html[] =   '</label>';
                                    }
                                $html[] = '</div>'; 
                            }
                            break;
                        
                        // Basic upload_image
                        case 'upload_image':
                            $html[] = '<table border="0">';
                            $html[] = '<tr>';
                            $html[] = '<td>';
                            $html[] = '<input class="upload-input-text" name="' . ($elm_id) . '" id="' . ($elm_id) . '_upload" type="text" value="' . ($val) . '" />';
                            
                            $html[] = '<script type="text/javascript">
								jQuery("#' . ($elm_id) . '_upload").data({
									"w": ' . ($value['thumbSize']['w']) . ',
									"h": ' . ($value['thumbSize']['h']) . ',
									"zc": ' . ($value['thumbSize']['zc']) . '
								});
							</script>';
                            
                            $html[] = '</td>';
                            $html[] = '<td>';
                            $html[] = '<a href="#" class="button upload_button" id="' . ($elm_id) . '">' . ($value['value']) . '</a> ';
                            $html[] = '<a href="#" class="button reset_button ' . $hide . '" id="reset_' . ($elm_id) . '" title="' . ($elm_id) . '">'. ( esc_html__('Remove', 'aa-woopagination') ) .'</a> ';
                            $html[] = '</td>';
                            $html[] = '</tr>';
                            $html[] = '</table>';
                            
                            $html[] = '<a class="thickbox" id="uploaded_image_' . ($elm_id) . '" href="' . ($val) . '" target="_blank">';
                            
                            if (!empty($val)) {
                                $imgSrc = $sp->image_resize($val, $value['thumbSize']['w'], $value['thumbSize']['h'], $value['thumbSize']['zc']);
                                $html[] = '<img style="border: 1px solid #dadada;" id="image_' . ($elm_id) . '" src="' . ($imgSrc) . '" />';
                            }
                            $html[] = '</a>';
                            
                            break;
                        
                        // Basic textarea
                        case 'textarea':
                            $cols = "120";
                            if (isset($value['cols'])) {
                                $cols = $value['cols'];
                            }
                            $height = "style='height:120px;'";
                            if (isset($value['height'])) {
                                $height = "style='height:{$value['height']};'";
                            }
                            
                            $html[] = '<textarea id="' . esc_attr($elm_id) . '" ' . $height . ' cols="' . ($cols) . '" name="' . ( $box_id ) . '[' . esc_attr( $elm_id ) . ']">' . esc_attr($val) . '</textarea>';
                            break;
                        
                        // Basic html/text message
                        case 'message':
                            $html[] = '<div class="sp-message sp-' . ($value['status']) . ' ' . ($this->tabs_elements($box, $elm_id)) . '">' . ($value['html']) . '</div>';
                            break;
                        
                        
                        // Basic html/text message
                        case 'html':
                            $html[] = str_replace("__box_id__", $box_id, $value['html']);
                            break;
						
                        // Select Box
                        case 'select':
                            $html[] = '<select ' . (isset($value['force_width']) ? "style='width:" . ($value['force_width']) . "px;'" : '') . ' name="' . ( $box_id ) . '[' . esc_attr( $elm_id ) . ']" id="' . esc_attr($elm_id) . '">';
                            
                            foreach ($value['options'] as $key => $option) {
                                $selected = '';
                                if ($val != '') {
                                    if ($val == $key) {
                                        $selected = ' selected="selected"';
                                    }
                                }
                                $html[] = '<option' . $selected . ' value="' . esc_attr($key) . '">' . esc_html($option) . '</option>';
                            }
                            $html[] = '</select>';
                            break;
                        
                        // multiselect Box
                        case 'multiselect':
                            $html[] = '<select multiple="multiple" size="3" name="[' . ( $box_id ) . '][' . esc_attr( $elm_id ) . '][]" id="' . esc_attr($elm_id) . '">';
                            
                            if (count($option) > 1) {
                                foreach ($value['options'] as $key => $option) {
                                    $selected = '';
                                    if ($val != '') {
                                        if (in_array($key, $val)) {
                                            $selected = ' selected="selected"';
                                        }
                                    }
                                    $html[] = '<option' . $selected . ' value="' . esc_attr($key) . '">' . esc_html($option) . '</option>';
                                }
                            }
                            $html[] = '</select>';
                            break;
                            
                        // multiselect Box
                        case 'multiselect_left2right':

                            $available = array(); $selected = array();
                            foreach ($value['options'] as $key => $option ) {
                                if( $val != '' ) {
                                    if ( in_array($key, $val) ) { $selected[] = $key; } 
                                }
                            }
                            $available = array_diff(array_keys($value['options']), $selected);
                            
                            $html[] = '<div class="sp-multiselect-half sp-multiselect-available" style="margin-right: 2%;">';
                            if( isset($value['info']['left']) ){
                                $html[] = '<h5>' . ( $value['info']['left'] ) . '</h5>';
                            }
                            $html[] = '<select multiple="multiple" size="' . (isset($value['rows_visible']) ? $value['rows_visible'] : 5) . '" name="[' . ( $box_id ) . '][' . esc_attr( $elm_id ) . '-available][]" id="' . esc_attr( $elm_id ) . '-available" class="multisel_l2r_available">';
                            
                            if(count($available) > 0){
                                foreach ($value['options'] as $key => $option ) {
                                    if ( !in_array($key, $available) ) continue 1;
                                    $html[] = '<option value="' . esc_attr( $key ) . '">' . esc_html( $option ) . '</option>';
                                } 
                            }
                            $html[] = '</select>';
                            
                            $html[] = '</div>';
                            
                            $html[] = '<div class="sp-multiselect-half sp-multiselect-selected">';
                            if( isset($value['info']['right']) ){
                                $html[] = '<h5>' . ( $value['info']['right'] ) . '</h5>';
                            }
                            $html[] = '<select multiple="multiple" size="' . (isset($value['rows_visible']) ? $value['rows_visible'] : 5) . '" name="[' . ( $box_id ) . '][' . esc_attr( $elm_id ) . '[]" id="' . esc_attr( $elm_id ) . '" class="multisel_l2r_selected">';
                            
                            if(count($selected) > 0){
                                foreach ($value['options'] as $key => $option ) {
                                    if ( !in_array($key, $selected) ) continue 1;
                                    $isselected = ' selected="selected"'; 
                                    $html[] = '<option'. $isselected .' value="' . esc_attr( $key ) . '">' . esc_html( $option ) . '</option>';
                                } 
                            }
                            $html[] = '</select>';
                            $html[] = '</div>';
                            $html[] = '<div style="clear:both"></div>';
                            $html[] = '<div class="multisel_l2r_btn" style="">';
                            $html[] = '<span style="display: inline-block; width: 24.1%; text-align: center;"><input id="' . esc_attr( $elm_id ) . '-moveright" type="button" value="'. ( esc_html__('Move Right', 'aa-woopagination') ) .'" class="moveright sp-button gray"></span>';
                            $html[] = '<span style="display: inline-block; width: 24.1%; text-align: center;"><input id="' . esc_attr( $elm_id ) . '-moverightall" type="button" value="'. ( esc_html__('Move Right All', 'aa-woopagination') ) .'" class="moverightall sp-button gray"></span>';
                            $html[] = '<span style="display: inline-block; width: 24.1%; text-align: center;"><input id="' . esc_attr( $elm_id ) . '-moveleft" type="button" value="'. ( esc_html__('Move Left', 'aa-woopagination') ) .'" class="moveleft sp-button gray"></span>';
                            $html[] = '<span style="display: inline-block; width: 24.1%; text-align: center;"><input id="' . esc_attr( $elm_id ) . '-moveleftall" type="button" value="'. ( esc_html__('Move Left All', 'aa-woopagination') ) .'" class="moveleftall sp-button gray"></span>';
                            $html[] = '</div>';
                        break;
                            
                        default:
							wp_die("Invalid filed types!");
                            
                    }

					// the element description
                    if (isset($value['desc'])){
                        $html[] = '<span class="sp-form-note">' . ($value['desc']) . '</span>';
					}

  					if (!in_array($value['type'], $noRowElements)) {
                        // close: .sp-form-row
                        $html[] = '</div></div>';
                    }
                }
                
                // sp-message use for status message, default it's hidden
                $html[] = '<div class="sp-message" id="sp-status-box" style="display:none;"></div>';
                
              
                // buttons for saving settings
                $html[] = '<div class="sp-button-row">
					<input type="submit" value="Save Settings" class="sp-button yellow sp-saveOptions" />
				</div>';
                
                // close: form
                $html[] = '</form>';
                
                // return the $html
                return implode("\n", $html);
            }
        }

        //make Tabs!
        private function tabs_header( $box ) {
            $html = array();

            // get tabs
            $tabs = isset($box['tabs']) ? $box['tabs'] : array();
 
            if (is_array($tabs) && count($tabs)>0) {
                $html[] = '<ul class="sp-settings-tabs">';
                foreach ($tabs as $key_tab => $value_tab) {
                    $html[] = '<li><a href="#' . ( $key_tab ) . '">' . ( $value_tab['label']  ) . '</a></li>';
                }
                $html[] = '</ul>';
            }

            // return the $html
            return implode("\n", $html);
        }

        private function tabs_elements($box, $elemKey) {
            // get tabs
            $__tabs = isset($box['tabs']) ? $box['tabs'] : array();

            $__ret = '';
            if (is_array($__tabs) && count($__tabs)>0) {
                foreach ($__tabs as $tabClass => $tabElements) {

                    $tabElements = $tabElements['elements'];
                    $tabElements = trim($tabElements);
                    $tabElements = array_map('trim', explode(',', $tabElements));
                    if (in_array($elemKey, $tabElements)) 
                        $__ret .= ($tabClass.' '); //support element on multiple tabs!
                }
            }
            return ' '.trim($__ret).' ';
        }
    }
}